FT232H - Heros Devices 0.11.1 documentation

Skip to content
Back to top
View this page

# FT232H

From: Adafruit

Class: `herosdevices.hardware.ftdi.FT232H`

Driver Quality Index: beta

Provide pin wrapping and GPIO abstraction.

see http://eblot.github.io/pyftdi/pinout.html

The device sn is written to the eeprom of the Adafruit FT232H chips. To do that follow this description: https://cdn-learn.adafruit.com/downloads/pdf/adafruit-ft232h-breakout.pdf?timestamp=1550211653 (section Erase EEPROM For Programming With FT_PROG)

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.ftdi.FT232H` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
device_sn | <class ‘str’> | QAO201901 |

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `FT232H` using BOSS.

    {
        "_id": "my_FT232H",
        "classname": "herosdevices.hardware.ftdi.FT232H",
        "arguments": {
            "device_sn": "QAO201901"
        }
    }

generated from signature

Inheritance